@@ -6,7 +6,7 @@ from datetime import datetime
 from selenium.webdriver.support.ui import WebDriverWait
 from selenium.webdriver.common.by import By
 from selenium.common.exceptions import TimeoutException
-from scrappier.exceptions.element_not_found_exception import ElementNotFoundException
+from .exceptions.element_not_found_exception import ElementNotFoundException
 
 class ElementFinder:
 
